@@ -127,10 +127,9 @@ class ActionGetCashAccountReport(AbstractAction):
                     payload=response_text,
                 )
         except Exception as e:
-            logger.fatal(response_raw.status_code)
-            logger.fatal(response_raw.text)
+            logger.fatal(response_raw)
             logger.fatal(e)
-            return False
+            return None
 
         return response
 
